==> nextcloud-16.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/is.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "_" : "_",
    "An error occurred while generating your backup codes" : "Villa kom upp við að búa til öryggisafritunarkóðana þína",
    "{name} backup codes" : "{name} öryggisafritunarkóðar",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Þetta eru öryggisafritunarkóðarnir þínir. Vistaðu þá og/eða prentaðu þá út, því þú munt ekki geta lesið þá aftur síðar í ferlinu",
    "Save backup codes" : "Vista öryggisafritunarkóða",
    "Print backup codes" : "Prenta öryggisafritunarkóða",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Öryggisafritunarkóðar hafa verið útbúnir. {used} af {total} kóðum hafa verið notaðir.",
    "Regenerate backup codes" : "Endurnýja öryggisafritunarkóða",
    "_icon-loading-small_::_generate-backup-codes_" : ["icon-loading-small","generate-backup-codes"],
    "If you regenerate backup codes, you automatically invalidate old codes." : "Ef þú endurnýjar öryggisafritunarkóða, gerir þú sjálfkrafa eldri kóða ógilda.",
    "Generate backup codes" : "Útbúa öryggisafritunarkóða",
    "You created two-factor backup codes for your account" : "Þú útbjóst tveggja-þrepa öryggisafritunarkóða fyrir aðganginn þinn",
    "Second-factor backup codes" : "Tveggja-þrepa öryggisafritunarkóðar",
    "Backup code" : "Öryggisafritunarkóði",
    "Use backup code" : "Nota öryggisafritunarkóða",
    "Two factor backup codes" : "Tveggja-þrepa öryggisafritunarkóðar",
    "A two-factor auth backup codes provider" : "Útgefandi tveggja-þrepa öryggisafritunarkóða",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Notaðu einn af öryggisafritunarkóðunum sem þú vistaðir þegar þú settir upp tveggja-þátta auðkenningu.",
    "Submit" : "Senda inn",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "Öryggisafritunarkóðar hafa verið útbúnir. {{used}} af {{total}} kóðum hafa verið notaðir.",
    "Nextcloud backup codes" : "Nextcloud öryggisafritunarkóðar",
    "activated" : "virkjað",
    "updated" : "uppfært",
    "mounted" : "tengt í skráakerfi",
    "deactivated" : "afvirkjað",
    "beforeCreate" : "beforeCreate",
    "created" : "búið til",
    "beforeUpdate" : "beforeUpdate",
    "beforeDestroy" : "beforeDestroy",
    "destroyed" : "eyðilagt",
    "beforeMount" : "beforeMount",
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "Þú hefur virkjað tveggja-þátta auðkenningu en hefur ekki ennþá útbúið öryggisafritunarkóða. Vertu viss um að gera það ef ske kynni að þú týndir staðfestingarþætti."
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-19.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/is.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Þú útbjóst tveggja-þrepa öryggisafritunarkóða fyrir aðganginn þinn",
    "Second-factor backup codes" : "Tveggja-þrepa öryggisafritunarkóðar",
    "Generate backup codes" : "Útbúa öryggisafritunarkóða",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Þú virkjaðir tveggja-þrepa auðkenningu en hefur ekki ennþá útbúið öryggisafritunarkóða. Þeir eru nauðsynlegir til að geta endurheimt aðganginn þinn fari svo að þú tapir seinni þætti auðkenningarinnar.",
    "Backup code" : "Öryggisafritunarkóði",
    "Use backup code" : "Nota öryggisafritunarkóða",
    "Two factor backup codes" : "Tveggja-þrepa öryggisafritunarkóðar",
    "A two-factor auth backup codes provider" : "Útgefandi tveggja-þrepa öryggisafritunarkóða",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Öryggisafritunarkóðar hafa verið útbúnir. {used} af {total} kóðum hafa verið notaðir.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Þetta eru öryggisafritunarkóðarnir þínir. Vistaðu þá og/eða prentaðu þá út, því þú munt ekki geta lesið þá aftur síðar í ferlinu",
    "Save backup codes" : "Vista öryggisafritunarkóða",
    "Print backup codes" : "Prenta öryggisafritunarkóða",
    "Regenerate backup codes" : "Endurnýja öryggisafritunarkóða",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Ef þú endurnýjar öryggisafritunarkóða, gerir þú sjálfkrafa eldri kóða ógilda.",
    "An error occurred while generating your backup codes" : "Villa kom upp við að búa til öryggisafritunarkóðana þína",
    "{name} backup codes" : "{name} öryggisafritunarkóðar",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Notaðu einn af öryggisafritunarkóðunum sem þú vistaðir þegar þú settir upp tveggja-þátta auðkenningu.",
    "Submit" : "Senda inn",
    "function" : "aðgerð",
    "_" : "_",
    "_icon-loading-small_::_generate-backup-codes_" : ["icon-loading-small","generate-backup-codes"]
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
